@@ -8,11 +8,10 @@ test_that("repGlm", {
                  PSU = "jkzone", repInd = "jkrep", imp = "imp", groups = "country",
                  formula = score~sex, family ="gaussian")))
   txt2 <- capture_output(res1 <- report(mod1, printGlm = TRUE))
-  
-  expect_equal(res1$est[c(1, 6, 11)], c(508.406, 502.607, 526.287))
-  expect_equal(dim(res1), c(15, 9))
+  expect_equal(res1[which(res1[,"parameter"] == "(Intercept)"),"est"], c(508.406, 502.607, 526.287))
+  expect_equal(dim(res1), c(18, 9))
   expect_equal(unique(res1$group), c("countryA", "countryB", "countryC"))
-  expect_equal(unique(res1$parameter), c("(Intercept)", "sexmale", "Nvalid", "R2", "R2nagel"))
+  expect_equal(unique(res1$parameter), c("(Intercept)", "Ncases", "sexmale", "Nvalid" , "R2", "R2nagel"  ))
 })
 
 
